## v0.2.1 - Apr/2019

- add `JOBLOG_CONFIG` setting
- add `live_updates` and `ping` mode

## v0.1.1 - Aug/2018

- add search and filter to admin view

## v0.1.0 - Jul/2018

- make printing to console optional
- add django unit-tests

## v0.0.1 - Jul/2018

- Copy-pasted together from various private projects, 'sanitized' and repackaged for PyPi
